# ElencoaccessiprogGetQueryParamData


## Fields

| Field              | Type               | Required           | Description        | Example            |
| ------------------ | ------------------ | ------------------ | ------------------ | ------------------ |
| `prognazacc`       | *Optional[str]*    | :heavy_minus_sign: | N/A                | 6744962            |
| `civico`           | *Optional[str]*    | :heavy_minus_sign: | N/A                | 1                  |
| `esp`              | *Optional[str]*    | :heavy_minus_sign: | N/A                | A                  |
| `specif`           | *Optional[str]*    | :heavy_minus_sign: | N/A                | ROSSO              |
| `metrico`          | *Optional[str]*    | :heavy_minus_sign: | N/A                | 1200               |
| `coord_x`          | *Optional[str]*    | :heavy_minus_sign: | N/A                | 12,5349017         |
| `coord_y`          | *Optional[str]*    | :heavy_minus_sign: | N/A                | 44,0191923         |
| `quota`            | *Optional[str]*    | :heavy_minus_sign: | N/A                | 50                 |
| `metodo`           | *Optional[str]*    | :heavy_minus_sign: | N/A                | 4                  |